@@ -45,7 +45,7 @@ class VectorThree(object):
         else:
             return self.C;
         
-    def put_by_ind(self, idx, val):
+    def put_by_idx(self, idx, val):
         if idx == 0:
             self.A = val
         elif idx == 1:
@@ -81,7 +81,7 @@ class VectorThree(object):
         strkey = "(" + str(round(self.A, rnd)) + ","
         strkey += str(round(self.B, rnd)) + ","  
         strkey += str(round(self.C, rnd)) + ")"  
-        return strKey
+        return strkey
             
     def get_point_pos(self, in_gap, in_width):    
         nums = int(in_width / in_gap)
